<?php
/**
 * @file
 * Aether's implementation to display a single Drupal page while offline.
 *
 * All the available variables are mirrored in html.tpl.php and page.tpl.php.
 * Some may be blank but they are provided for consistency.
 *
 * @see template_preprocess()
 * @see template_preprocess_maintenance_page()
 */
?><!DOCTYPE html>
<!--[if IEMobile 7]><html class="iem7" <?php print $html_attributes; ?>><![endif]-->
<!--[if lte IE 6]><html class="ie6 ie6-7 ie6-8" <?php print $html_attributes; ?>><![endif]-->
<!--[if (IE 7)&(!IEMobile)]><html class="ie7 ie6-7 ie6-8" <?php print $html_attributes; ?>><![endif]-->
<!--[if IE 8]><html class="ie8 ie6-8" <?php print $html_attributes; ?>><![endif]-->
<!--[if (gte IE 9)|(gt IEMobile 7)]><!--><html <?php print $html_attributes . $rdf_namespaces; ?>><!--<![endif]-->

<head profile="<?php print $grddl_profile; ?>">
  <?php print $head; ?>
  <title><?php print $head_title; ?></title>

  <?php if ($add_responsive_meta): ?>
    <meta name="viewport" content="width=device-width, target-densityDpi=160dpi, initial-scale=1">
    <meta name="MobileOptimized" content="width">
    <meta name="HandheldFriendly" content="true">
    <meta name="apple-mobile-web-app-capable" content="yes">
  <?php endif; ?>
  <meta http-equiv="cleartype" content="on">
  <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">

  <?php print $styles; ?>
  <?php print $scripts; ?>
  <?php if ($add_responsive_tables): ?>
    <script src="<?php print $base_path . $path_to_aether; ?>/js/responsive-tables.js"></script>
  <?php endif; ?>
  <?php if ($add_respond_js): ?>
    <!--[if lt IE 9]>
    <script src="http://cdnjs.cloudflare.com/ajax/libs/respond.js/1.1.0/respond.min.js"></script>
    <![endif]-->
  <?php endif; ?>
  <?php if ($add_html5_shim): ?>
    <!--[if lt IE 9]>
    <script src="<?php print $base_path . $path_to_aether; ?>/js/html5.js"></script>
    <![endif]-->
  <?php endif; ?>
  <?php if ($add_selectivizr_js): ?>
    <!--[if (gte IE 6)&(lte IE 8)]>
    <script src="http://cdnjs.cloudflare.com/ajax/libs/selectivizr/1.0.2/selectivizr-min.js"></script>
    <![endif]-->
  <?php endif; ?>
  <?php if ($add_imgsizer_js): ?>
    <!--[if lt IE 8]>
    <script src="<?php print $base_path . $path_to_aether; ?>/js/imgsizer.js"></script>
    <![endif]-->
  <?php endif; ?>
</head>
<body class="<?php print $classes; ?>">

<div id="page" class="<?php print $classes; ?>"<?php print $attributes; ?>>

  <header id="header" role="banner" class="clearfix">

    <?php if ($page['user_first'] || $page['user_second']): ?>
      <div class="user-columns-wrapper clearfix">
        <div class="limiter">
          <div class="user-row g-all-row">
            <?php print render($page['user_first']); ?>
            <?php print render($page['user_second']); ?>
          </div> <!-- /.g-all-row -->
        </div> <!-- /.limiter -->
      </div> <!-- /.wrapper -->
    <?php endif; ?>

    <div class="branding-wrapper clearfix">
      <div class="limiter">
        <div class="branding-row g-all-row">
          <?php if ($logo || $site_name || $site_slogan || $secondary_menu || $page['branding']): ?>
            <?php print render($page['branding']); ?>
          <?php endif; ?>
        </div> <!-- /g-all-row -->
      </div> <!-- /limiter -->
    </div> <!-- /branding-wrapper -->

    <?php if ($page['header_first'] || $page['header_second'] || $page['header_third']): ?>
      <div class="header-columns-wrapper clearfix">
        <div class="limiter">
          <div class="header-row g-all-row">
            <?php print render($page['header_first']); ?>
            <?php print render($page['header_second']); ?>
            <?php print render($page['header_third']); ?>
          </div> <!-- /#header-columns -->
        </div> <!-- /.limiter -->
      </div> <!-- /.header-columns-wrapper -->
    <?php endif; ?>

    <?php if ($main_menu): ?>
      <nav id="main-menu" class="main-menu menu">
        <div class="main-menu-wrapper clearfix">
          <div class="limiter">
            <div class="main-menu-row g-all-row">
              <div class="<?php print $grid_width ?>">
              <?php if ($main_menu): ?>
                <?php print theme('links', array('links' => $main_menu,'attributes' => array('id' => 'primary','class' => array('links','clearfix','main-menu')))); ?>
              <?php endif; ?>
              <?php if ($page['navigation']): ?>
                <?php print render($page['navigation']); ?>
              <?php endif; ?>
              </div> <!-- /grid width -->
            </div> <!-- /.limiter -->
          </div> <!-- /g-all-row -->
        </div> <!-- /.main-menu-wrapper -->
      </nav>
    <?php endif; ?>

    <?php if ($page['navigation_first'] || $page['navigation_second']): ?>
      <div class="navigation-columns-wrapper clearfix">
        <div class="limiter">
          <div class="navigation-row g-all-row">
            <?php if ($page['navigation_first']): ?>
              <?php print render($page['navigation_first']); ?>
            <?php endif; ?>
            <?php if ($page['navigation_second']): ?>
              <?php print render($page['navigation_second']); ?>
            <?php endif; ?>
          </div> <!-- /g-all-row -->
        </div> <!-- /limiter -->
      </div> <!-- /.navigation-columns-wrapper -->
    <?php endif; ?>

  </header> <!-- /header -->

  <?php if ($page['feature']): ?>
    <section id="feature" class="clearfix">
      <div class="feature-wrapper clearfix">
        <div class="limiter">
          <div class="feature-row g-all-row">
            <?php print render($page['feature']); ?>
          </div>
        </div>
      </div>
    </section>
  <?php endif; ?>

  <section id="main">

    <?php if ($page['preface_first'] || $page['preface_second'] || $page['preface_third']): ?>
      <div class="preface-wrapper clearfix">
        <div class="limiter">
          <div class="preface-row g-all-row">
            <?php print render($page['preface_first']); ?>
            <?php print render($page['preface_second']); ?>
            <?php print render($page['preface_third']); ?>
          </div> <!-- /#preface-columns -->
        </div>
      </div>
    <?php endif; ?>

    <div class="content-wrapper clearfix">
      <div class="limiter">
        <div class="content-row g-all-row">
          <div id="content" <?php print $attributes; ?>>
            <div <?php print $content_attributes; ?>>
              <?php if ($breadcrumb || $title|| $messages || $tabs || $action_links): ?>
              <div id="content-header">
                <?php print $breadcrumb; ?>
                <?php if ($page['highlight']): ?>
                  <div id="highlight"><?php print render($page['highlight']) ?></div>
                <?php endif; ?>
                <?php if ($title): ?>
                  <h1 class="title"><?php print $title; ?></h1>
                <?php endif; ?>
                <?php print $messages; ?>
                <?php print render($page['help']); ?>
                <?php if ($tabs): ?>
                  <div class="tabs"><?php print render($tabs); ?></div>
                <?php endif; ?>
                <?php if ($action_links): ?>
                  <ul class="action-links"><?php print render($action_links); ?></ul>
                <?php endif; ?>
              </div> <!-- /#content-header -->
              <?php endif; ?>
              <div id="content-area">
                <?php print render($page['content']) ?>
              </div>
              <?php print $feed_icons; ?>
            </div> <!-- /.content-inner -->
          </div> <!-- /content -->
          <?php print render($page['sidebar_first']); ?>
          <?php print render($page['sidebar_second']); ?>
        </div> <!-- /.g-all-row -->
      </div> <!-- /.limiter -->
    </div> <!-- /.content-wrapper -->

    <?php if ($page['postscript_first'] || $page['postscript_second'] || $page['postscript_third'] || $page['postscript_fourth']): ?>
      <div class="postscript-wrapper clearfix">
        <div class="limiter">
          <div class="postscript-row g-all-row">
            <?php print render($page['postscript_first']); ?>
            <?php print render($page['postscript_second']); ?>
            <?php print render($page['postscript_third']); ?>
            <?php print render($page['postscript_fourth']); ?>
          </div> <!-- /#postscript-columns /.g-all-row -->
        </div> <!-- /.limiter -->
      </div> <!-- /.powerscript-wrapper -->
    <?php endif; ?>

  </section> <!-- /main -->

  <div class="push"></div>
</div> <!-- /page -->

<footer id="footer">

  <?php if ($page['footer_first'] || $page['footer_second'] || $page['footer_third'] || $page['footer_fourth']): ?>
    <div class="footer-columns-wrapper">
      <div class="limiter">
        <div class="footer-row g-all-row">
          <?php print render($page['footer_first']); ?>
          <?php print render($page['footer_second']); ?>
          <?php print render($page['footer_third']); ?>
          <?php print render($page['footer_fourth']); ?>
        </div> <!-- /#footer-columns /.g-all-row -->
      </div> <!-- /.limiter -->
    </div> <!-- /.footer-columns-wrapper -->
  <?php endif; ?>

  <?php if ($page['footer']): ?>
    <div class="footer-wrapper">
      <div class="limiter">
        <div class="footer-row g-all-row">
          <?php print render($page['footer']); ?>
        </div> <!-- /.g-all-row -->
      </div> <!-- /.limiter -->
    </div> <!-- /.footer-wrapper -->
  <?php endif; ?>

</footer>

</div> <!-- /page -->
</html>
